@@ -40,12 +40,16 @@ def koilable(
 
         def koiled_exit(self, *args, **kwargs):
             unkoil(self.__aexit__, *args, **kwargs)
-            getattr(self, fieldname).__exit__(*args, **kwargs)
+            koil = getattr(self, fieldname, None)
+            if koil is not None:
+                koil.__exit__(None, None, None)
             setattr(self, fieldname, None)
 
         def disconnect(self):
             unkoil(self.__aexit__, None, None, None)
-            getattr(self, fieldname).__exit__(None, None, None)
+            koil = getattr(self, fieldname, None)
+            if koil is not None:
+                koil.__exit__(None, None, None)
             setattr(self, fieldname, None)
 
         async def adisconnect(self):
